@@ -16,6 +16,7 @@ utils_module = Extension(
         join("src", "bluetooth_data_tools", "_utils_impl.pyx"),
     ],
     language="c",
+    extra_compile_args=["-O3", "-g0"],
 )
 
 time_module = Extension(
@@ -24,7 +25,22 @@ time_module = Extension(
         join("src", "bluetooth_data_tools", "_time_impl.pyx"),
     ],
     language="c",
+    extra_compile_args=["-O3", "-g0"],
 )
+TO_CYTHONIZE = [
+    "src/bluetooth_data_tools/gap.py",
+    "src/bluetooth_data_tools/utils.py",
+]
+
+EXTENSIONS = [
+    Extension(
+        ext.removeprefix("src/").removesuffix(".py").replace("/", "."),
+        [ext],
+        language="c",
+        extra_compile_args=["-O3", "-g0"],
+    )
+    for ext in TO_CYTHONIZE
+]
 
 
 class BuildExt(build_ext):
@@ -47,8 +63,7 @@ def build(setup_kwargs: Any) -> None:
                     [
                         time_module,
                         utils_module,
-                        "src/bluetooth_data_tools/gap.py",
-                        "src/bluetooth_data_tools/utils.py",
+                        *EXTENSIONS,
                     ],
                     compiler_directives={"language_level": "3"},  # Python 3
                 ),
